// src/pages/index.tsx

import { useState } from 'react';

const HomePage = () => {
  const [url, setUrl] = useState('');
  const [tinyUrl, setTinyUrl] = useState('');
  const [error, setError] = useState('');

  const handleSubmit = async (e: { preventDefault: () => void; }) => {
    e.preventDefault();
    setTinyUrl('');
    setError('');
    try {
      const response = await fetch('http://localhost:3000/url-shortener/shorten', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ url }),
      });

      const data = await response.json();
      if (response.ok && data.status === 201) {
        setTinyUrl(data.data);
      } else {
        setError(data.error || 'An error occurred while shortening the URL');
      }
    } catch (error) {
      setError('Failed to connect to the server');
    }
  };

  return (
    <div className="flex flex-col items-center justify-center min-h-screen bg-gray-100">
      <div className="bg-white p-6 rounded shadow-md w-full max-w-md">
        <h1 className="text-2xl font-bold mb-4 text-center">Shorten Your URL</h1>
        <form onSubmit={handleSubmit} className="mb-4">
          <input
            type="url"
            className="border border-gray-300 p-2 w-full rounded mb-2"
            placeholder="Enter URL here"
            value={url}
            onChange={(e) => setUrl(e.target.value)}
          />
          <button className="w-full bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded">
            Shorten
          </button>
        </form>
        {tinyUrl && (
          <p className="text-green-600 bg-green-100 p-2 rounded">
            Shortened URL: 
            <a href={`http://localhost:3000/url-shortener/${tinyUrl}`} target="_blank" rel="noopener noreferrer" className="underline ml-1">
              {tinyUrl}
            </a>
          </p>
        )}
        {error && <p className="text-red-600 bg-red-100 p-2 rounded">{error}</p>}
      </div>
    </div>
  );
};

export default HomePage;
